@@ -36,6 +36,11 @@ struct result_of< RESULT_TYPE (*)(INPUT_TYPE) >{
 	typedef RESULT_TYPE type ;
 } ;
 
+template <typename RESULT_TYPE, typename U1, typename U2>
+struct result_of< RESULT_TYPE (*)(U1, U2) >{
+	typedef RESULT_TYPE type ;
+} ;
+
 }
 }     
 
