@@ -23,13 +23,17 @@
 #define Rcpp__vector__Matrix_h
    
 template <int RTYPE> 
-class Matrix : public Vector<RTYPE> {
+class Matrix : public Vector<RTYPE>, public MatrixBase<RTYPE,true, Matrix<RTYPE> > {
 public:
+	struct r_type : traits::integral_constant<int,RTYPE>{} ;
+	struct can_have_na : traits::true_type{} ;
+	
 	typedef Vector<RTYPE> VECTOR ;
 	typedef typename VECTOR::iterator iterator ;
     typedef typename VECTOR::converter_type converter_type ;
     typedef typename VECTOR::stored_type stored_type ;
-    	
+    typedef typename VECTOR::Proxy Proxy ;
+    
 	Matrix() : VECTOR() {}
 	
 	Matrix(SEXP x) throw(not_compatible) : VECTOR(){
@@ -67,6 +71,32 @@ public:
 		return *this ;
 	}
 	
+	template <bool NA, typename MAT>
+    Matrix( const MatrixBase<RTYPE,NA,MAT>& other ) : VECTOR() {
+    	int nr = other.nrow() ;
+    	int nc = other.ncol() ;
+    	SEXP x = PROTECT( Rf_allocVector( RTYPE, nr * nc ) ) ;
+    	SEXP d = PROTECT( Rf_allocVector( INTSXP, 2) ) ;
+    	INTEGER(d)[0] = nr ;
+    	INTEGER(d)[1] = nc ;
+    	Rf_setAttrib( x, Rf_install("dim"), d ) ;
+    	RObject::setSEXP( x ) ;
+    	UNPROTECT( 2 ) ;
+    	import_matrix_expression<NA,MAT>( other, nr * nc ) ;
+	}
+   
+private:
+	
+	template <bool NA, typename MAT>
+    void import_matrix_expression( const MatrixBase<RTYPE,NA,MAT>& other, int n ){
+    	iterator start = VECTOR::begin() ; 
+		for( int i=0; i<n; i++, ++start){
+			*start = other[i] ;
+		}
+    }
+
+public:
+	
 	template <typename U>
     void fill_diag( const U& u){
     	fill_diag__dispatch( typename traits::is_trivial<RTYPE>::type(), u ) ;	
@@ -79,9 +109,23 @@ public:
     	return res ;
     }
     
+    inline Proxy operator[]( int i ){
+    	return static_cast< Vector<RTYPE>* >( this )->operator[]( i ) ;
+    }
+    inline Proxy operator()( int i, int j ){
+    	return static_cast< Vector<RTYPE>* >( this )->operator()( i, j ) ;
+    }
+    
+    inline Proxy operator[]( int i ) const {
+    	return static_cast< const Vector<RTYPE>* >( this )->operator[]( i ) ;
+    }
+    inline Proxy operator()( int i, int j ) const {
+    	return static_cast< const Vector<RTYPE>* >( this )->operator()( i, j ) ;
+    }
+    
 private:
 	virtual void update(){
-		RCPP_DEBUG( "%s::update", DEMANGLE(Matrix) ) ;
+		RCPP_DEBUG_1( "%s::update", DEMANGLE(Matrix) ) ;
 		VECTOR::update_vector() ;
 	}
 	
@@ -90,7 +134,7 @@ private:
 		SEXP elem = PROTECT( converter_type::get( u ) ) ;
 		int n = Matrix::ncol() ;
 		int offset = n +1 ;
-		iterator it( Matrix::begin()) ;
+		iterator it( VECTOR::begin()) ;
 		for( int i=0; i<n; i++){
     		*it = ::Rf_duplicate( elem );
     		it += offset; 
@@ -103,13 +147,37 @@ private:
 		stored_type elem = converter_type::get( u ) ;
 		int n = Matrix::ncol() ;
 		int offset = n + 1 ;
-		iterator it( Matrix::begin()) ;
+		iterator it( VECTOR::begin()) ;
 		for( int i=0; i<n; i++){
     		*it = elem ;
     		it += offset; 
     	}
     }
+
+public:
+	inline int ncol() const throw(not_a_matrix) {
+    	return VECTOR::dims()[1]; 
+    }
+    inline int nrow() const throw(not_a_matrix){
+    	return VECTOR::dims()[0]; 
+    }
+    inline int cols() const throw(not_a_matrix){ 
+    	return VECTOR::dims()[1]; 
+    }
+    inline int rows() const throw(not_a_matrix){ 
+    	return VECTOR::dims()[0]; 
+    }
 	    
+	typedef MatrixRow<RTYPE> Row ;
+	typedef MatrixColumn<RTYPE> Column ;
+
+	inline Row row( int i ){ return Row( *this, i ) ; }
+	inline Column column( int i ){ return Column(*this, i ) ; }
+	
+	inline iterator begin() const{ return VECTOR::begin() ; }
+	inline iterator end() const{ return VECTOR::end() ; }
+	 
+    
 } ;
 
 #endif
